ApiClient class abstract interface

The contract any HTTP client must satisfy.

Implementers

Properties

baseUrl Uri
Base URL for all requests. Must not have a trailing slash.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() Future<void>
Close/dispose underlying resources.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(ApiRequest request) Future<ApiResponse>
Send a request and return a buffered response.
sendStreaming(ApiRequest request) Future<StreamedApiResponse>
Send a request and return a streaming response.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited