ApiSecurityScheme class final

A security scheme defined in an OpenAPI spec.

Constructors

ApiSecurityScheme({required String name, required ApiSecuritySchemeType type, String? scheme, String? bearerFormat, String? parameterName, ApiKeyLocation? location, String? openIdConnectUrl, List<ApiOAuthFlow> flows = const []})
Creates a security scheme with the given name and type.
const

Properties

bearerFormat String?
A hint for the bearer token format (e.g. JWT).
final
flows List<ApiOAuthFlow>
The OAuth 2.0 flows supported by this scheme.
final
hashCode int
The hash code for this object.
no setterinherited
location ApiKeyLocation?
Where the API key is sent.
final
name String
The scheme name as declared in the spec.
final
openIdConnectUrl String?
The OpenID Connect discovery URL.
final
parameterName String?
The name of the API key parameter.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheme String?
The HTTP authentication scheme (e.g. bearer, basic).
final
type ApiSecuritySchemeType
The type of security scheme.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited