ApiSecuritySchemeType enum

The type of security scheme defined in an OpenAPI spec.

Inheritance
Available extensions

Values

apiKey → const ApiSecuritySchemeType

API key authentication.

http → const ApiSecuritySchemeType

HTTP authentication (e.g. Basic, Bearer).

mutualTls → const ApiSecuritySchemeType

Mutual TLS authentication.

oauth2 → const ApiSecuritySchemeType

OAuth 2.0 authentication.

openIdConnect → const ApiSecuritySchemeType

OpenID Connect authentication.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ApiSecuritySchemeType>
A constant List of the values in this enum, in order of their declaration.