nextResponse property
The response to return for the next send call.
Defaults to an empty 200 response.
Implementation
ApiResponse nextResponse;
The response to return for the next send call.
Defaults to an empty 200 response.
ApiResponse nextResponse;