nextStreamedResponse property
The streaming response to return for the next sendStreaming call.
Implementation
StreamedApiResponse? nextStreamedResponse;
The streaming response to return for the next sendStreaming call.
StreamedApiResponse? nextStreamedResponse;