onRequest property
Optional callback to dynamically generate responses based on the request.
If set, takes precedence over nextResponse.
Implementation
ApiResponse Function(ApiRequest request)? onRequest;
Optional callback to dynamically generate responses based on the request.
If set, takes precedence over nextResponse.
ApiResponse Function(ApiRequest request)? onRequest;