ApiException<T, E> class
Network-level failure (DNS, timeout, connection refused).
- Inheritance
- Implementers
Constructors
- ApiException(Object exception, StackTrace stackTrace)
-
Creates an API exception result wrapping the given
exception.const
Properties
- dataOrThrow → T
-
Returns the success data, or throws if the result is an error/exception.
no setteroverride
- exception → Object
-
The underlying exception that caused the failure.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace
-
The stack trace of the original exception.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited